﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Myriadbits.DiskSpaceAnalyzer
{

	/// <summary>
	/// The different units
	/// </summary>
	public enum UnitTypes
	{
		B = 0,
		KB,
		MB,
		GB,
		Auto
	};


	/// <summary>
	/// Static class to get a size in the requested unit
	/// </summary>
	public static class UnitTypesExtensions
	{
		public static string GetUnitText(this UnitTypes unitType, double size)
		{
			// Draw the mega bytes
			double divider = 1;
			string unit = "B";
			switch (unitType)
			{
				case UnitTypes.KB:
					divider = 1024;
					unit = "KB";
					break;
				case UnitTypes.MB:
					divider = 1024 * 1024;
					unit = "MB";
					break;
				case UnitTypes.GB:
					divider = 1024 * 1024 * 1024;
					unit = "GB";
					break;
				case UnitTypes.Auto:
					if (size > (1024 * 1024 * 1024))
					{
						divider = 1024 * 1024 * 1024;
						unit = "GB";
					}
					else if (size > (1024 * 1024))
					{
						divider = 1024 * 1024;
						unit = "MB";
					}
					else if (size > 1024)
					{
						divider = 1024;
						unit = "KB";
					}
					break;
			}
			size = size / divider;
			if (divider == 1)
				return string.Format("{0:### ### ### ### ##0} {1}", size, unit); // No need to show fractions for bytes
			else
				return string.Format("{0:### ### ### ### ##0.0} {1}", size, unit);
		}
	}
}
